@@ -8,7 +8,7 @@
 #
 
 from .core.caching import CACHE as cache
-from .core.metadata import init_metadata
+from .core.initialise import initialise
 from .core.settings import SETTINGS as settings
 from .datasets import Dataset, dataset, load_dataset, register_dataset
 from .normalize import ALL
@@ -17,11 +17,9 @@ from .plotting import options as plotting_options
 from .plotting import plot_map
 from .readers import Reader
 from .sources import Source, load_source, register_source, source
+from .version import __version__
 from .wrappers import Wrapper
 
-__version__ = "0.8.2"
-
-
 __all__ = [
     "ALL",
     "cache",
@@ -40,6 +38,7 @@ __all__ = [
     "Source",
     "register_dataset",
     "register_source",
+    "__version__",
 ]
 
-init_metadata()
+initialise()
