@@ -8,8 +8,8 @@
 #
 
 import inspect
+import logging
 import os
-import warnings
 from collections import defaultdict
 
 import yaml
@@ -18,6 +18,9 @@ from climetlab.core.plugins import directories
 from climetlab.decorators import locked
 from climetlab.utils.html import css
 
+LOG = logging.getLogger(__name__)
+
+
 YAML_FILES = None
 
 IGNORE = ["magics.yaml", "colours.yaml", "conventions.yaml", "config.yaml"]
@@ -41,7 +44,7 @@ def _guess(data, path):
         if "mmap" in data["magics"]:
             return "projections"
 
-        warnings.warn("Cannot guess collection for %s", path)
+        LOG.warning("Cannot guess collection for %s", path)
     return "unknown"
 
 
@@ -104,8 +107,8 @@ def _load_yaml_files():
                         else:
                             collection[name] = e
 
-                except Exception as e:
-                    warnings.warn(f"Cannot process YAML file {path} {owner} ({e})")
+                except Exception:
+                    LOG.exception("Cannot process YAML file %s (%s)", path, owner)
 
     return YAML_FILES
 
