@@ -177,6 +177,7 @@ class Driver:
 
     def plot_xarray(self, ds, variable: str, dimensions: dict = None):
         tmp = self.temporary_file(".nc")
+        tmp = "tmp.nc"
         field = ds[variable].isel({} if dimensions is None else dimensions)
         dataset = field.to_dataset()
 
@@ -321,7 +322,7 @@ class Driver:
 
         return Display(path, metadata=dict(width=width))
 
-    def save(self, path):  # noqa C901
+    def save(self, path):
 
         self.finalise()
 
