@@ -18,7 +18,7 @@ from climetlab.decorators import locked
 LOG = logging.getLogger(__name__)
 
 
-class Reader(Base):
+class Reader(Base, os.PathLike):
 
     appendable = False  # Set to True if the data can be appened to and existing file
     binary = True
@@ -57,10 +57,6 @@ class Reader(Base):
     def sel(self, *args, **kwargs):
         raise NotImplementedError()
 
-    @classmethod
-    def multi_merge(cls, readers):
-        return None
-
     def cache_file(self, *args, **kwargs):
         return self.source.cache_file(*args, **kwargs)
 
@@ -80,6 +76,9 @@ class Reader(Base):
                     break
                 f.write(chunk)
 
+    def __fspath__(self):
+        return self.path
+
 
 _READERS = {}
 
