@@ -14,19 +14,19 @@ from . import Reader
 LOG = logging.getLogger(__name__)
 
 
-try:
-    import codc as odc
-except Exception:
-    import pyodc as odc
-
-    LOG.debug("Using pure Python odc decoder.")
-
-
 class ODBReader(Reader):
-    def to_pandas(self):
-        return odc.read_odb(self.path, single=True)
+    def to_pandas(self, **kwargs):
+        try:
+            import codc as odc
+        except Exception:
+            import pyodc as odc
+
+            LOG.debug("Using pure Python odc decoder.")
+
+        odc_read_odb_kwargs = kwargs.get("odc_read_odb_kwargs", {})
+        return odc.read_odb(self.path, single=True, *odc_read_odb_kwargs)
 
 
-def reader(source, path, magic):
+def reader(source, path, magic, deeper_check):
     if magic[:5] == b"\xff\xffODA":
         return ODBReader(source, path)
