@@ -37,12 +37,38 @@ def offline(off):
     OFFLINE = off
 
 
-def dummy():
+def dummy_watcher():
     pass
 
 
+def mimetype_to_extension(mimetype, compression, default=".unknown"):
+    EXTENSIONS = {
+        None: "",
+        "gzip": ".gz",
+        "xz": ".xz",
+        "bzip2": ".bz2",
+    }
+    if mimetype is None:
+        extension = default
+    else:
+        extension = mimetypes.guess_extension(mimetype)
+
+    return extension + EXTENSIONS[compression]
+
+
+def canonical_extension(path):
+    _, ext = os.path.splitext(path)
+    ext = mimetype_to_extension(*mimetypes.guess_type(path), default=ext)
+    # Looks like mimetypes as .cdf before .nc
+    # TODO: report it to Python's bug tracker
+    EXTENSIONS = {".cdf": ".nc"}
+
+    return EXTENSIONS.get(ext, ext)
+
+
 class Downloader:
     def __init__(self, owner):
+        # TODO: use weakref instead
         self.owner = owner
 
     def local_path(self, url):
@@ -50,16 +76,16 @@ class Downloader:
 
     def extension(self, url):
         url_no_args = url.split("?")[0]
-
-        base, ext = os.path.splitext(url_no_args)
-        if ext == "":
-            base, ext = os.path.splitext(url)
-
-        _, tar = os.path.splitext(base)
-        if tar == ".tar":
-            ext = ".tar" + ext
-
-        return ext
+        base = os.path.basename(url_no_args)
+        extensions = []
+        while True:
+            base, ext = os.path.splitext(base)
+            if not ext:
+                break
+            extensions.append(ext)
+        if not extensions:
+            extensions.append(".unknown")
+        return "".join(reversed(extensions))
 
     def download(self, url, target):
         if os.path.exists(target):
@@ -120,7 +146,12 @@ class HTTPDownloader(Downloader):
             self._url = url
             self._headers = {}
             try:
-                r = requests.head(url, verify=self.owner.verify, allow_redirects=True)
+                r = requests.head(
+                    url,
+                    headers=self.owner.http_headers,
+                    verify=self.owner.verify,
+                    allow_redirects=True,
+                )
                 r.raise_for_status()
                 for k, v in r.headers.items():
                     self._headers[k.lower()] = v
@@ -133,17 +164,11 @@ class HTTPDownloader(Downloader):
         return self._headers
 
     def extension(self, url):
-        EXCEPTIONS = (".tgz", ".tar.gz")
 
         headers = self.headers(url)
 
         ext = super().extension(url)
 
-        if ext not in EXCEPTIONS:
-            if "content-type" in headers:
-                if headers["content-type"] != "application/octet-stream":
-                    ext = mimetypes.guess_extension(headers["content-type"])
-
         if "content-disposition" in headers:
             value, params = cgi.parse_header(headers["content-disposition"])
             assert value == "attachment", value
@@ -176,6 +201,7 @@ class HTTPDownloader(Downloader):
             stream=True,
             verify=self.owner.verify,
             timeout=SETTINGS.get("url-download-timeout"),
+            headers=self.owner.http_headers,
         )
         r.raise_for_status()
 
@@ -197,6 +223,10 @@ class HTTPDownloader(Downloader):
         return self.headers(url)
 
     def out_of_date(self, url, path, cache_data):
+
+        if SETTINGS.get("check-out-of-date-urls"):
+            return False
+
         if cache_data is not None:
 
             # TODO: check 'cache-control' to see if we should check the etag
@@ -204,16 +234,18 @@ class HTTPDownloader(Downloader):
                 pass
 
             if "expires" in cache_data:
-                try:
-                    expires = parse_date(cache_data["expires"])
-                    now = pytz.UTC.localize(datetime.datetime.utcnow())
-                    if expires > now:
-                        LOG.debug("URL %s not expired (%s > %s)", url, expires, now)
-                        return False
-                except Exception:
-                    LOG.exception(
-                        "Failed to check URL expiry date '%s'", cache_data["expires"]
-                    )
+                if cache_data["expires"] != "0":  # HTTP1.0 legacy
+                    try:
+                        expires = parse_date(cache_data["expires"])
+                        now = pytz.UTC.localize(datetime.datetime.utcnow())
+                        if expires > now:
+                            LOG.debug("URL %s not expired (%s > %s)", url, expires, now)
+                            return False
+                    except Exception:
+                        LOG.exception(
+                            "Failed to check URL expiry date '%s'",
+                            cache_data["expires"],
+                        )
 
             headers = self.headers(url)
             cached_etag = cache_data.get("etag")
@@ -221,11 +253,15 @@ class HTTPDownloader(Downloader):
 
             if cached_etag != remote_etag:
                 LOG.warning("Remote content of URL %s has changed", url)
-                if SETTINGS.get("download-updated-urls"):
+                if (
+                    SETTINGS.get("download-out-of-date-urls")
+                    or self.owner.update_if_out_of_date
+                ):
                     LOG.warning("Invalidating cache version and re-downloading %s", url)
                     return True
                 LOG.warning(
-                    "To enable automatic downloading of updated URLs set the 'download-updated-urls' setting to True",
+                    "To enable automatic downloading of updated URLs set the 'download-out-of-date-urls'"
+                    " setting to True",
                 )
             else:
                 LOG.debug("Remote content of URL %s unchanged", url)
@@ -312,23 +348,36 @@ class Url(FileSource):
         verify=True,
         watcher=None,
         force=None,
+        # extension=None,
+        http_headers=None,
+        update_if_out_of_date=False,
         mirror=DEFAULT_MIRROR,
         **kwargs,
     ):
+        # TODO: re-enable this feature
+        extension = None
+
         self.url = url
         LOG.debug("URL %s", url)
 
         self.filter = filter
         self.merger = merger
         self.verify = verify
-        self.watcher = watcher if watcher else dummy
+        self.watcher = watcher if watcher else dummy_watcher
+        self.update_if_out_of_date = update_if_out_of_date
+        self.http_headers = http_headers if http_headers else {}
 
         if mirror:
             url = mirror(url)
 
         o = urlparse(url)
         downloader = DOWNLOADERS[o.scheme](self)
-        extension = downloader.extension(url)
+
+        if extension and extension[0] != ".":
+            extension = "." + extension
+
+        if extension is None:
+            extension = downloader.extension(url)
 
         self.path = downloader.local_path(url)
         if self.path is not None:
